/*
 * callblocker - A call blocker app for FxOS.
 * Copyright (C) 2015 MiKael NAVARRO
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/* DOMContentLoaded is fired once the document has been loaded and parsed,
   but without waiting for other external resources to load (css/images/etc)
   That makes the app more responsive and perceived as faster.
   https://developer.mozilla.org/Web/Reference/Events/DOMContentLoaded
*/
window.addEventListener('DOMContentLoaded', function() {
    /* We'll ask the browser to use strict code to help us catch errors earlier.
       https://developer.mozilla.org/Web/JavaScript/Reference/Functions_and_function_scope/Strict_mode */
    'use strict';
    
    var translate = navigator.mozL10n.get;
    
    /* We want to wait until the localisations library has loaded all the strings.
       So we'll tell it to let us know once it's ready. */
    navigator.mozL10n.once(start);

    /* Global variables */
    //var myStorage = Window.localStorage;
    var anumber = 0;  // phone number

    /* Main/entry point */
    function start() {
	/* We're using textContent because inserting content from external sources into your page 
	   using innerHTML can be dangerous.
	   https://developer.mozilla.org/Web/API/Element.innerHTML#Security_considerations */
	//document.getElementById('setup-instructions').textContent = translate('setup_instructions');

	if (storageAvailable('localStorage')) {
	    console.log("Yippee! We can use localStorage awesomeness.");
	}
	else {
	    console.log("Too bad, no localStorage for us!");
	}

	// Display the list of phone numbers black-listed
	//localStorage.setItem("0123456789", "blocked");
	//localStorage.setItem("0245668000", "blocked");
	printNumbers();

	// Telephony object
	var tel = navigator.mozTelephony;

	// Receiving a call
	tel.onincoming = function (event) {
	    var incomingCall = event.call;
	    
	    // Get the number of the incoming call
	    console.log(incomingCall.id);

	    // See if the incoming call is in the block list?
	    console.log(localStorage.getItem(incomingCall.id.number));
	    if (localStorage.getItem(incomingCall.id.number)) {
		incomingCall.hangUp();
	    }
	};

	document.getElementById('blockbtn').addEventListener('click', function(e) {
	    anumber = document.getElementById("anumber").value;
	    blockNumber(anumber);
	    printNumbers();
	});

	document.getElementById('unblockbtn').addEventListener('click', function(e) { 
	    anumber = document.getElementById("anumber").value;
	    unblockNumber(anumber);
	    printNumbers();
	});

    }
});

// Test if web storage is available?
function storageAvailable(type) {
    try {
	var storage = window[type], x = '__storage_test__';
	storage.setItem(x, x);
	storage.removeItem(x);
	return true;
    }
    catch(e) {
	return false;
    }
};

/* Add phone number to block list */
function blockNumber(anumber) {
    if (anumber !== "" && localStorage.getItem(anumber) == null) {
	localStorage.setItem(anumber, "blocked");
	console.log(anumber + " added to block list");
    }
    else {
	console.log(anumber + " already in block list");
    }
}
		
/* Remove phone number from block list */
function unblockNumber(anumber) {
    if (anumber !== "" && localStorage.getItem(anumber) !== null) {
	localStorage.removeItem(anumber);
	console.log(anumber + " removed from block list");	
    }
    else {
	console.log(anumber + " not in block list");
    }
}

/* Display list of block numbers */
function printNumbers() {
    var blockList = document.getElementById("block-lst");
    var listLength = localStorage.length;

    if (listLength == 0) {
	blockList.innerHTML = "<tr><td>No number to be blocked</td></tr>";
    }
    else {
	blockList.innerHTML = "";  // init block list
	for (var i=0; i<listLength; i++) {
	    //var number = String(localStorage.key(i));
	    blockList.innerHTML += "<tr><td>" + localStorage.key(i) + "</td></tr>";
	}
    }
}
